@@ -9,12 +9,19 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+static void freePropDict(prop_dictionary_t* pdict)
+{
+    assert(pdict != NULL);
+    if (*pdict == NULL) return;
+    prop_object_release(*pdict);
+}
+
 static const char* detectCpuTemp(double* current)
 {
-    FF_AUTO_CLOSE_FD int fd = open(_PATH_SYSMON, O_RDONLY);
-    if (fd < 0) return "open(_PATH_SYSMON, O_RDONLY) failed";
+    FF_AUTO_CLOSE_FD int fd = open(_PATH_SYSMON, O_RDONLY | O_CLOEXEC);
+    if (fd < 0) return "open(_PATH_SYSMON, O_RDONLY | O_CLOEXEC) failed";
 
-    prop_dictionary_t root = NULL;
+    __attribute__((__cleanup__(freePropDict))) prop_dictionary_t root = NULL;
     if (prop_dictionary_recv_ioctl(fd, ENVSYS_GETDICTIONARY, &root) < 0)
         return "prop_dictionary_recv_ioctl(ENVSYS_GETDICTIONARY) failed";
 
@@ -44,7 +51,8 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
 {
     if (ffSysctlGetString("machdep.cpu_brand", &cpu->name) != NULL &&
         ffSysctlGetString("machdep.dmi.processor-version", &cpu->name) != NULL &&
-        ffSysctlGetString("hw.cpu0.name", &cpu->name) != NULL)
+        ffSysctlGetString("hw.cpu0.name", &cpu->name) != NULL &&
+        ffSysctlGetString("hw.model", &cpu->name) != NULL)
     {
         ffStrbufSetS(&cpu->name, "Unknown CPU");
     }
@@ -56,10 +64,11 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
     cpu->coresLogical = cpu->coresPhysical;
     cpu->coresOnline = (uint16_t) ffSysctlGetInt("hw.ncpuonline", cpu->coresLogical);
 
-    ffCPUDetectSpeedByCpuid(cpu);
+    ffCPUDetectByCpuid(cpu);
 
     uint32_t freq = (uint32_t) ffSysctlGetInt("machdep.cpu.frequency.target", 0);
     if (freq == 0) freq = (uint32_t) (ffSysctlGetInt64("hw.cpu0.clock_frequency", 0) / 1000000);
+    if (freq == 0) freq = (uint32_t) ffSysctlGetInt("machdep.dmi.processor-frequency", 0);
     if (freq > cpu->frequencyBase) cpu->frequencyBase = freq;
 
     cpu->temperature = FF_CPU_TEMP_UNSET;
