@@ -196,21 +196,5 @@ void ffConnectDisplayServerImpl(FFDisplayServerResult* ds)
         }
     }
 
-    const FFOSResult* os = ffDetectOS();
-
-    char* str_end;
-    const char* version = os->version.chars;
-    unsigned long osNum = strtoul(version, &str_end, 10);
-    if (str_end != version)
-    {
-        if (osNum > 15) { // Tahoe
-            ffStrbufSetStatic(&ds->dePrettyName, "Liquid Glass");
-        } else if (osNum < 10) {
-            ffStrbufSetStatic(&ds->dePrettyName, "Platinum");
-        } else {
-            ffStrbufSetStatic(&ds->dePrettyName, "Aqua");
-        }
-    }
-
     detectDisplays(ds);
 }
