@@ -1,6 +1,7 @@
 #pragma once
 
 #include "fastfetch.h"
+#include "modules/users/option.h"
 
 typedef struct FFUserResult
 {
@@ -11,4 +12,4 @@ typedef struct FFUserResult
     uint64_t loginTime; // ms
 } FFUserResult;
 
-const char* ffDetectUsers(FFlist* users);
+const char* ffDetectUsers(FFUsersOptions* options, FFlist* users);
