@@ -40,13 +40,13 @@ const char* ffDetectWifi(FFlist* result)
     ffStrbufInit(&item->conn.bssid);
     ffStrbufInit(&item->conn.protocol);
     ffStrbufInit(&item->conn.security);
-    item->conn.signalQuality = 0.0/0.0;
-    item->conn.rxRate = 0.0/0.0;
-    item->conn.txRate = 0.0/0.0;
+    item->conn.signalQuality = -DBL_MAX;
+    item->conn.rxRate = -DBL_MAX;
+    item->conn.txRate = -DBL_MAX;
     item->conn.channel = 0;
     item->conn.frequency = 0;
 
-    ffStrbufAppendS(&item->inf.status, yyjson_get_str(yyjson_obj_get(root, "supplicant_state")));
+    ffStrbufAppendJsonVal(&item->inf.status, yyjson_obj_get(root, "supplicant_state"));
     if(!item->inf.status.length)
     {
         ffStrbufAppendS(&item->inf.status, "Unknown");
@@ -59,9 +59,9 @@ const char* ffDetectWifi(FFlist* result)
     double rssi = yyjson_get_num(yyjson_obj_get(root, "rssi"));
     item->conn.signalQuality = rssi >= -50 ? 100 : rssi <= -100 ? 0 : (rssi + 100) * 2;
 
-    ffStrbufAppendS(&item->inf.description, yyjson_get_str(yyjson_obj_get(root, "ip")));
-    ffStrbufAppendS(&item->conn.bssid, yyjson_get_str(yyjson_obj_get(root, "bssid")));
-    ffStrbufAppendS(&item->conn.ssid, yyjson_get_str(yyjson_obj_get(root, "ssid")));
+    ffStrbufAppendJsonVal(&item->inf.description, yyjson_obj_get(root, "ip"));
+    ffStrbufAppendJsonVal(&item->conn.bssid, yyjson_obj_get(root, "bssid"));
+    ffStrbufAppendJsonVal(&item->conn.ssid, yyjson_obj_get(root, "ssid"));
     item->conn.frequency = (uint16_t) yyjson_get_int(yyjson_obj_get(root, "frequency_mhz"));
     item->conn.txRate = yyjson_get_num(yyjson_obj_get(root, "link_speed_mbps"));
     item->conn.channel = ffWifiFreqToChannel(item->conn.frequency);
