@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_COLORS_MODULE_NAME "Colors"
 
-void ffPrintColors(FFColorsOptions* options);
+bool ffPrintColors(FFColorsOptions* options);
 void ffInitColorsOptions(FFColorsOptions* options);
 void ffDestroyColorsOptions(FFColorsOptions* options);
+
+extern FFModuleBaseInfo ffColorsModuleInfo;
