@@ -9,6 +9,9 @@ typedef struct FFCommandOptions
     FFstrbuf shell;
     FFstrbuf param;
     FFstrbuf text;
+    bool useStdErr;
+    bool parallel;
+    bool splitLines;
 } FFCommandOptions;
 
 static_assert(sizeof(FFCommandOptions) <= FF_OPTION_MAX_SIZE, "FFCommandOptions size exceeds maximum allowed size");
