@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_CPU_MODULE_NAME "CPU"
 
-void ffPrintCPU(FFCPUOptions* options);
+bool ffPrintCPU(FFCPUOptions* options);
 void ffInitCPUOptions(FFCPUOptions* options);
 void ffDestroyCPUOptions(FFCPUOptions* options);
+
+extern FFModuleBaseInfo ffCPUModuleInfo;
