@@ -4,7 +4,7 @@
 
 #define FF_CPUCACHE_MODULE_NAME "CPUCache"
 
-void ffPrintCPUCache(FFCPUCacheOptions* options);
+bool ffPrintCPUCache(FFCPUCacheOptions* options);
 void ffInitCPUCacheOptions(FFCPUCacheOptions* options);
 void ffDestroyCPUCacheOptions(FFCPUCacheOptions* options);
 
