@@ -4,58 +4,32 @@
 #include "util/textModifier.h"
 #include "util/stringUtils.h"
 
-void ffPrintCustom(FFCustomOptions* options)
+bool ffPrintCustom(FFCustomOptions* options)
 {
     ffPrintFormat(FF_CUSTOM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, 0, ((FFformatarg[]) {}));
-}
-
-bool ffParseCustomCommandOptions(FFCustomOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_CUSTOM_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return true;
 }
 
 void ffGenerateCustomJsonConfig(FFCustomOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyCustomOptions))) FFCustomOptions defaultOptions;
-    ffInitCustomOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
 void ffParseCustomJsonObject(FFCustomOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_CUSTOM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_CUSTOM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
-    .name = FF_CUSTOM_MODULE_NAME,
-    .description = "Print a custom string, with or without key",
-    .parseCommandOptions = (void*) ffParseCustomCommandOptions,
-    .parseJsonObject = (void*) ffParseCustomJsonObject,
-    .printModule = (void*) ffPrintCustom,
-    .generateJsonConfig = (void*) ffGenerateCustomJsonConfig,
-};
-
 void ffInitCustomOptions(FFCustomOptions* options)
 {
-    options->moduleInfo = ffModuleInfo;
     ffOptionInitModuleArg(&options->moduleArgs, "");
     ffStrbufSetStatic(&options->moduleArgs.key, " ");
 }
@@ -64,3 +38,13 @@ void ffDestroyCustomOptions(FFCustomOptions* options)
 {
     ffOptionDestroyModuleArg(&options->moduleArgs);
 }
+
+FFModuleBaseInfo ffCustomModuleInfo = {
+    .name = FF_CUSTOM_MODULE_NAME,
+    .description = "Print a custom string, with or without key",
+    .initOptions = (void*) ffInitCustomOptions,
+    .destroyOptions = (void*) ffDestroyCustomOptions,
+    .parseJsonObject = (void*) ffParseCustomJsonObject,
+    .printModule = (void*) ffPrintCustom,
+    .generateJsonConfig = (void*) ffGenerateCustomJsonConfig,
+};
