@@ -4,7 +4,7 @@
 
 #define FF_OPENCL_MODULE_NAME "OpenCL"
 
-void ffPrintOpenCL(FFOpenCLOptions* options);
+bool ffPrintOpenCL(FFOpenCLOptions* options);
 void ffInitOpenCLOptions(FFOpenCLOptions* options);
 void ffDestroyOpenCLOptions(FFOpenCLOptions* options);
 
