@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_SEPARATOR_MODULE_NAME "Separator"
 
-void ffPrintSeparator(FFSeparatorOptions* options);
+bool ffPrintSeparator(FFSeparatorOptions* options);
 void ffInitSeparatorOptions(FFSeparatorOptions* options);
 void ffDestroySeparatorOptions(FFSeparatorOptions* options);
+
+extern FFModuleBaseInfo ffSeparatorModuleInfo;
