@@ -4,7 +4,7 @@
 
 #define FF_SHELL_MODULE_NAME "Shell"
 
-void ffPrintShell(FFShellOptions* options);
+bool ffPrintShell(FFShellOptions* options);
 void ffInitShellOptions(FFShellOptions* options);
 void ffDestroyShellOptions(FFShellOptions* options);
 
