@@ -4,7 +4,7 @@
 
 #define FF_TERMINAL_MODULE_NAME "Terminal"
 
-void ffPrintTerminal(FFTerminalOptions* options);
+bool ffPrintTerminal(FFTerminalOptions* options);
 void ffInitTerminalOptions(FFTerminalOptions* options);
 void ffDestroyTerminalOptions(FFTerminalOptions* options);
 
