@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_THEME_MODULE_NAME "Theme"
 
-void ffPrintTheme(FFThemeOptions* options);
+bool ffPrintTheme(FFThemeOptions* options);
 void ffInitThemeOptions(FFThemeOptions* options);
 void ffDestroyThemeOptions(FFThemeOptions* options);
+
+extern FFModuleBaseInfo ffThemeModuleInfo;
