@@ -3,6 +3,7 @@
 #include "common/io/io.h"
 #include "util/stringUtils.h"
 
+#if !_WIN32
 const char* ffFindExecutableInPath(const char* name, FFstrbuf* result)
 {
     char* path = getenv("PATH");
@@ -47,13 +48,19 @@ const char* ffFindExecutableInPath(const char* name, FFstrbuf* result)
     ffStrbufClear(result);
     return "Executable not found";
 }
+#else
+#include <windows.h>
 
-bool ffIsAbsolutePath(const char* path)
+const char* ffFindExecutableInPath(const char* name, FFstrbuf* result)
 {
-    #ifdef _WIN32
-    return (ffCharIsEnglishAlphabet(path[0]) && path[1] == ':' && (path[2] == '\\' || path[2] == '/')) // drive letter path
-        || (path[0] == '\\' && path[1] == '\\'); // UNC path
-    #else
-    return path[0] == '/';
-    #endif
+    char buffer[MAX_PATH + 1];
+    DWORD length = SearchPathA(NULL, name, ".exe", sizeof(buffer), buffer, NULL);
+    if (length == 0)
+    {
+        ffStrbufClear(result);
+        return "Executable not found";
+    }
+    ffStrbufSetS(result, buffer);
+    return NULL;
 }
+#endif
