@@ -9,7 +9,6 @@ typedef struct FFPlatformSysinfo
     FFstrbuf release;
     FFstrbuf version;
     FFstrbuf architecture;
-    FFstrbuf displayVersion;
     uint32_t pageSize;
 } FFPlatformSysinfo;
 
@@ -22,6 +21,7 @@ typedef struct FFPlatform
     FFstrbuf exePath; // The real path of current exe
 
     FFstrbuf userName;
+    FFstrbuf fullUserName;
     FFstrbuf hostName;
     FFstrbuf userShell;
 
